% DemoConductivitySolver
%
% Overview:
%   Demonstration of the application of the Neumann-Poincare operator to
%   conductivity problem. We can derive an exact analytical solution in 
%   polar coordinates as follows:
%       u(r,theta) = r cos(theta) - (k-1)/(k+1) R^2 * 1/r * cos(theta),    |r| > R
%       u(r,theta) = 2/(k+1) * r cos(theta),    |r| <= R.
%   We will evaluate numerically the solution 'u' on the circle |(x,y)|= Reval(=10)
%   and then compare it with the exact solution.
%
% System:
%   Inclusion:          A circle of radius R=5 centered at (0,0).
%   External field:     h(x,y)=x.
%
% References:
%   Mathematical and Computational Methods in Photonics - Tutorial Notes
%
% Authors:
%   Habib Ammari, Brian Fitzpatrick, Matias Ruiz, Sanghyeon Yu
clc;
clear all;
close all

% --------------------------------------------------
% System parameters
% --------------------------------------------------
cond = 3.0; % conductivity = 3.0
lambda=(cond+1)/(2*(cond-1));
nbPoints=50;

R=5; Reval=10; % circular inclusion
D= ellipse (R,R,0,0,nbPoints);
Omega= ellipse (Reval,Reval,0,0,nbPoints);

% --------------------------------------------------
% Solve the integral equation (lambda*I-KDstar)[phi] = \p h/\p\nu.
% --------------------------------------------------
A=lambda*eye(nbPoints)-Kstar(D); 
b=D.normal(1,:)';
phi=A\b; 

% --------------------------------------------------
% Compute the numerical solution and the exact solution.
% --------------------------------------------------
h=Omega.points(1,:)'; % evaluate 'h' on the circle |(x,y)|=Reval
u_num=h+SingleL(Omega,D)*phi;
u_exact = h - (cond-1)/(cond+1) * R^2 * Omega.points(1,:)' / Reval^2;

% --------------------------------------------------
% Display the solution.
% --------------------------------------------------
fprintf('\nIn theory | Numerically');
[u_exact(1:25) u_num(1:25)]
figure(1)
hold on
plot(1:nbPoints, u_exact, 'r-');
plot(1:nbPoints, u_num, 'b+');
legend('u_{e}','u_{n}','Location','southeast')